#
# ovirt-hosted-engine-ha -- ovirt hosted engine high availability
# Copyright (C) 2013-2018 Red Hat, Inc.
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation; either
# version 2.1 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public
# License along with this library; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
#

%define enable_autotools 1
%define enable_tests 0

%global         package_version 2.3.6
%global         package_name ovirt-hosted-engine-ha
%global         engine_ha_bindir  /usr/share/ovirt-hosted-engine-ha
%global         engine_ha_confdir /etc/ovirt-hosted-engine-ha
%global         engine_ha_libdir  %{python_sitelib}/ovirt_hosted_engine_ha
%global         engine_ha_logdir  /var/log/ovirt-hosted-engine-ha
%global         engine_ha_rundir  /var/run/ovirt-hosted-engine-ha
%global         engine_ha_statedir /var/lib/ovirt-hosted-engine-ha

# {Downstream only
%global commit 277d2e0da1c8b32d29394dfe7ad38eb5bdb80bad
%global shortcommit %(c=%{commit}; echo ${c:0:7})
%define enable_autotools 1
# }

%global         vdsm_user vdsm
%global         vdsm_group kvm
%global         vdsm_version 4.30.0

Summary:        oVirt Hosted Engine High Availability Manager
Name:           ovirt-hosted-engine-ha
Version:        2.3.6
Release:        1%{?release_suffix}%{?dist}
License:        LGPLv2+
URL:            http://www.ovirt.org
Source0:        http://resources.ovirt.org/pub/src/%{name}/%{name}-%{package_version}.tar.gz
Group:          Applications/System

BuildArch:      noarch

Requires:       python
Requires:       python-daemon
Requires:       python-six
Requires:       sanlock >= 3.7.3
Requires:       sanlock-python >= 3.7.3
Requires:       sudo
Requires(pre):  vdsm >= %{vdsm_version}
Requires(post): vdsm >= %{vdsm_version}
Requires:       vdsm >= %{vdsm_version}
Requires:       vdsm-client >= %{vdsm_version}
Requires:       vdsm-python >= %{vdsm_version}
Conflicts:      ovirt-hosted-engine-setup < 2.3

%if 0%{?rhel} > 0 && 0%{?rhel} <= 7
Requires:       python-lxml
%else
Requires:       python2-lxml
%endif

# Otopi is needed for the cli client
Requires:       otopi >= 1.8.0

BuildRequires:  python
BuildRequires:  python2-devel

%if 0%{?enable_tests}
BuildRequires:  python-nose
BuildRequires:  python-mock
BuildRequires:  vdsm >= %{vdsm_version}
BuildRequires:  vdsm-client >= %{vdsm_version}
BuildRequires:  vdsm-python >= %{vdsm_version}
ExclusiveArch:  x86_64
%endif

%if 0%{?rhel} > 0 && 0%{?rhel} <= 7
BuildRequires:  python-lxml
%else
BuildRequires:  python2-lxml
%endif

%{?systemd_requires}
BuildRequires:  systemd

%if 0%{?enable_autotools}
BuildRequires:  autoconf
BuildRequires:  automake
%endif

%description
Hosted engine manager for oVirt project.


%prep
%setup -q -n %{name}-%{package_version}

%build
%if 0%{?enable_autotools}
./autogen.sh --system
%endif
%configure \
        --docdir="%{_docdir}/%{name}-%{version}" \
        --disable-python-syntax-check \
        %{?conf}
make %{?_smp_mflags}

%if 0%{?enable_tests}
%check
make test
%endif

%install
make %{?_smp_mflags} install DESTDIR="%{buildroot}"

install -dDm 0700 %{buildroot}%{engine_ha_logdir}

install -dDm 0700 %{buildroot}%{engine_ha_rundir}
install -dDm 0700 %{buildroot}%{engine_ha_statedir}
# Install the systemd scripts
install -Dm 0644 initscripts/ovirt-ha-agent.service %{buildroot}%{_unitdir}/ovirt-ha-agent.service
install -Dm 0644 initscripts/ovirt-ha-broker.service %{buildroot}%{_unitdir}/ovirt-ha-broker.service

install -dDm 0750 %{buildroot}%{_sysconfdir}/sudoers.d
install -Dm 0440 sudoers/sudoers %{buildroot}%{_sysconfdir}/sudoers.d/60_ovirt-ha

%files
%license COPYING
%doc README
%doc doc/*.html doc/*.js

%dir %{engine_ha_confdir}
%config(noreplace) %{engine_ha_confdir}/agent-log.conf
%config(noreplace) %{engine_ha_confdir}/agent.conf
%config(noreplace) %{engine_ha_confdir}/broker-log.conf

%dir %{engine_ha_confdir}/notifications
%config(noreplace) %{engine_ha_confdir}/notifications/*

%dir %{engine_ha_bindir}
%{engine_ha_bindir}/ovirt-ha-agent
%{engine_ha_bindir}/ovirt-ha-broker

%dir %{engine_ha_libdir}
%{engine_ha_libdir}/*
%{_unitdir}/ovirt-ha-agent.service
%{_unitdir}/ovirt-ha-broker.service

%config(noreplace) %{_sysconfdir}/sudoers.d/60_ovirt-ha


%defattr(-, %{vdsm_user}, %{vdsm_group}, -)
%dir %{engine_ha_logdir}
%ghost %dir %{engine_ha_rundir}

%dir %{engine_ha_statedir}
%config(noreplace) %{engine_ha_statedir}/ha.conf
%config(noreplace) %{engine_ha_statedir}/broker.conf

%defattr(640, %{vdsm_user}, %{vdsm_group}, -)
%ghost %{engine_ha_logdir}/agent.log
%ghost %{engine_ha_logdir}/broker.log


%post
# Fix answerfile ownership for upgrade purposes: if the configuration volume
# is still not on the shared storage (upgrading from 3.5 time), ovirt-ha-agent
# is going to create it uploading local files.
# ovirt-ha-agent runs as vdsm user so we have to be sure it could read the
# initial answerfile.
if [ -e %{_sysconfdir}/ovirt-hosted-engine/answers.conf ] ; then
    chown root:kvm %{_sysconfdir}/ovirt-hosted-engine/answers.conf
fi
# Copy previous broker.conf on upgrade path
if [ $1 -gt 1 ] ; then
    if [ -e "%{engine_ha_confdir}/broker.conf" ]; then
            cp "%{engine_ha_confdir}/broker.conf" "%{engine_ha_statedir}/broker.conf"
            chown %{vdsm_user}:%{vdsm_group}  "%{engine_ha_statedir}/broker.conf"
    fi
fi
%systemd_post ovirt-ha-agent.service
%systemd_post ovirt-ha-broker.service
if [ "$1" -eq 1 ] ; then
#We don't want the service to be started by default before the system
#is configured and Hosted Engine VM deployed
    /usr/bin/systemctl --no-reload disable ovirt-ha-agent.service
    /usr/bin/systemctl --no-reload disable ovirt-ha-broker.service
fi
# Fix logfile ownership for upgrade purposes
if [ -e %{engine_ha_logdir}/agent.log ] ; then
    chown %{vdsm_user}:%{vdsm_group} %{engine_ha_logdir}/agent.log
fi
if [ -e %{engine_ha_logdir}/broker.log ] ; then
    chown %{vdsm_user}:%{vdsm_group} %{engine_ha_logdir}/broker.log
fi


%preun
%systemd_preun ovirt-ha-agent.service
%systemd_preun ovirt-ha-broker.service



%postun
%systemd_postun_with_restart ovirt-ha-agent.service
%systemd_postun_with_restart ovirt-ha-broker.service


%changelog
* Tue Nov 12 2019 Evgeny Slutsky <eslutsky@redhat.com> - 2.3.6-1
- 2.3.6-1
- Rebase on upstream 2.3.6-1

* Tue Aug 20 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.5-1
- 2.3.5-1
- Rebase on upstream 2.3.5-1

* Mon Aug 05 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.4-1
- 2.3.4-1
- Rebase on upstream 2.3.4-1

* Tue Jun 25 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.3-1
- 2.3.3-1
- Rebase on upstream 2.3.3-1

* Tue Jun 11 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.2-1
- 2.3.2-1
- Rebase on upstream 2.3.2-1

* Tue Jan 22 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.1-1
- 2.3.1-1
- Rebase on upstream 2.3.1-1

* Wed Jan 09 2019 Simone Tiraboschi <stirabos@redhat.com> - 2.3.0-1
- 2.3.0-1
- Rebase on upstream 2.3.0-1

* Wed Nov 21 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.3.0-0.1.alpha
- 2.3.0-0.1.alpha
- Rebase on upstream 2.3.0-0.1.beta

* Thu Jul 19 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.16-1
- Rebase on upstream 2.2.16
- Resolves: BZ#1596331

* Fri Jun 29 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.15-1
- Rebase on upstream 2.2.15
- Resolves: BZ#1596331
- Resolves: BZ#1393839

* Thu Jun 14 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.14-1
- Rebase on upstream 2.2.14
- Resolves: BZ#1581784
- Resolves: BZ#1579103

* Wed May 30 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.13-1
- Rebase on upstream 2.2.13
- Resolves: BZ#1581784
- Resolves: BZ#1579103
- Resolves: BZ#1582489
- Resolves: BZ#1583712

* Wed May 23 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.12-1
- Rebase on upstream 2.2.12
- Resolves: BZ#1581784
- Resolves: BZ#1571119

* Tue Apr 24 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.11-1
- Rebase on upstream 2.2.11
- Resolves: BZ#1458711
- Resolves: BZ#1567615

* Thu Apr  5 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.10-1
- Rebase on upstream 2.2.10
- Resolves: BZ#1458711
- Resolves: BZ#1560666

* Tue Mar 27 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.9-1
- Rebase on upstream 2.2.9
- Resolves: BZ#1458711

* Mon Mar 26 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.8-1
- Rebase on upstream 2.2.8
- Resolves: BZ#1458711

* Wed Mar 14 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.7-1
- Rebase on upstream 2.2.7
- Resolves: BZ#1458711
- Resolves: BZ#1543988

* Tue Feb 20 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.6-1
- Rebase on upstream 2.2.6
- Resolves: BZ#1458711
- Resolves: BZ#1545105

* Wed Feb 14 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.5-1
- Rebase on upstream 2.2.5
- Resolves: BZ#1458711
- Resolves: BZ#1443819

* Wed Jan 17 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.4-1
- Rebase on upstream 2.2.4
- Resolves: BZ#1458711
- Resolves: BZ#1519289

* Wed Jan 10 2018 Simone Tiraboschi <stirabos@redhat.com> - 2.2.3-1
- Rebase on upstream 2.2.3
- Resolves: BZ#1458711
- Resolves: BZ#1527394

* Thu Dec 14 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.2-1
- Rebase on upstream 2.2.2
- Resolves: BZ#1458711
- Resolves: BZ#1512534
- Resolves: BZ#1525601

* Mon Dec 11 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.2.1-1
- Rebase on upstream 2.2.1
- Resolves: BZ#1458711
- Resolves: BZ#1524331

* Mon Nov 27 2017 Sandro Bonazzola <sbonazzo@redhat.com> - 2.2.0-1
- Rebase on upstream 2.2.0
- Resolves: BZ#1337914
- Resolves: BZ#1378310
- Resolves: BZ#1417708
- Resolves: BZ#1458711
- Resolves: BZ#1480039
- Resolves: BZ#1485883
- Resolves: BZ#1498327

* Thu May 25 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.1-1
- 2.1.1-1
- Resolves: BZ#1455605

* Mon Apr 24 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.6-1

* Thu Apr 13 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.5-2
- Resolves: BZ#1401359

* Wed Mar 22 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.5-1
- Rebase on upstream 2.1.0.5
- Resolves: BZ#1379404

* Thu Mar  2 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.4-1
- Rebase on upstream 2.1.0.4
- Resolves: BZ#1379404

* Wed Feb 15 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.3-1
- Rebase on upstream 2.1.0.3
- Resolves: BZ#1379404

* Thu Feb 09 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.2-1
- Rebase on upstream 2.1.0.2
- Resolves: BZ#1379404

* Thu Jan 26 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0.1-1
- Rebase on upstream 2.1.0.1
- Resolves: BZ#1379404
- Resolves: BZ#1411783
- Resolves: BZ#1415994

* Mon Jan 16 2017 Simone Tiraboschi <stirabos@redhat.com> - 2.1.0-1
- Rebase on upstream 2.1.0
- Resolves: BZ#1379404

* Wed Sep 07 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.4-1
- Rebase on upstream 2.0.4
- Resolves: BZ#1373972
- Resolves oVirt:
  - BZ#1365242

* Wed Aug 24 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 2.0.3-1
- Rebase on upstream 2.0.3
- Resolves: BZ#1369784
- Resolves oVirt:
  - BZ#1367732

* Tue Aug 09 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.2-1
- 2.0.2-1
- Resolves: BZ#1364034

* Tue Jul 12 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 2.0.1-1
- 2.0.1-1
- Resolves: BZ#1346341

* Tue May 31 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.0-1
- 2.0.0-1
- Resolves: BZ#1306952

* Thu May 19 2016 Simone Tiraboschi <stirabos@redhat.com> - 2.0.0-0.1.beta1
- 2.0.0-0.1.beta1
- Resolves: BZ#1306952

* Mon Mar 14 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 2.0.0-0.1.master.git6d76852
- 2.0.0-0.1.master.git6d76852

* Fri Feb 12 2016 Sandro Bonazzola <sbonazzo@redhat.com> - 2.0.0-0.0.master.gitfb4c0e9
- 2.0.0-0.0.master.gitfb4c0e9
- Resolves: BZ#1306952

* Mon Dec 21 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.3.6-1
- Rebase on upstream 1.3.3.6
- Resolves: BZ#1284954
- Resolves: BZ#1280310

* Fri Dec 18 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.3.5-1
- Rebase on upstream 1.3.3.5
- Resolves: BZ#1284954

* Thu Dec 17 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.3.4-1
- Rebase on upstream 1.3.3.4
- Resolves: BZ#1284954

* Wed Dec  9 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.3.3-1
- Rebase on upstream 1.3.3.3
- Resolves: BZ#1280310

* Wed Dec  9 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.3.2-1
- Rebase on upstream 1.3.3.2
- Resolves: BZ#1284954

* Tue Dec  1 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.3.1-1
- Rebase on upstream 1.3.3.1-1
- Resolves: BZ#1284954

* Tue Nov 24 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.3-1
- Rebase on upstream 1.3.3
- Resolves: BZ#1030441

* Wed Nov 18 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.3-0.1.master.git71b535e
- Resolves: BZ#1030441
- Resolves oVirt:
  - BZ#1278725
  - BZ#1279548
  - BZ#1281539

* Mon Nov  2 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.2.1-1
- Rebase on upstream 1.3.2.1
- Resolves: BZ#1234906

* Mon Nov  2 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.2-1
- Rebase on upstream 1.3.2
- Resolves: BZ#1234906
- Resolves: BZ#1276740
- Resolves: BZ#1276650
- Resolves: BZ#1268892

* Tue Oct 13 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.1-1
- Rebase on upstream 1.3.1
- Resolves: BZ#1234906

* Thu Sep 24 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-1
- Resolves: BZ#1234906

* Tue Sep 22 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.6.beta.git9223c91
- Resolves: BZ#1258465

* Wed Sep 09 2015 Martin Sivak <msivak@redhat.com> - 1.3.0-0.4.beta.git9a2bd43
- Resolves: rhbz#1254671
- Resolves: rhbz#1208489
- Resolves: rhbz#1150087

* Tue Sep  1 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.4.beta.git1bcfe28
- Resolves: BZ#1234906

* Wed Aug 19 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.3.beta.git183a4ff
- Resolves: BZ#1172511
- Resolves: BZ#1238823
- Resolves: BZ#1254745

* Tue Aug 11 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.2.beta.git1daf4e8
- Resolves: BZ#1190071
- Resolves: BZ#1229774
- Resolves: BZ#1248539

* Mon Jun 29 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.1.alpha.git5f8c290
- Resolves: BZ#1116469

* Thu Apr 16 2015 Sandro Bonazzola <sbonazzo@redhat.com> - 1.3.0-0.0.master.git0c1bea5
- Resolves: BZ#1164226
- Resolves: BZ#1150087

